#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SPLATTED_MINIMUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SPLATTED_MINIMUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/splatted_minimum.hpp>

#endif
